# Potodo
Potodo, a Flawless TODO/progress listing CLI tool for po files

## Installation

```bash
pip install potodo
```

## Usage

```bash
potodo -p PATH -r ORG/REPO
```
This will run potodo in the given `PATH` and search for open issues on `github.com/ORG/REPO`